@@ -7,18 +7,14 @@
 #ifndef KDEVPLATFORM_ABBREVIATIONS_H
 #define KDEVPLATFORM_ABBREVIATIONS_H
 
-#include <QVarLengthArray>
-
 #include <language/languageexport.h>
 
-class QStringList;
-class QStringRef;
-class QString;
+#include <QStringList>
 
 namespace KDevelop {
 class Path;
 
-KDEVPLATFORMLANGUAGE_EXPORT bool matchesAbbreviation(const QStringRef& word, const QString& typed);
+KDEVPLATFORMLANGUAGE_EXPORT bool matchesAbbreviation(QStringView word, const QString& typed);
 
 KDEVPLATFORMLANGUAGE_EXPORT bool matchesPath(const QString& path, const QString& typed);
 
@@ -32,7 +28,7 @@ KDEVPLATFORMLANGUAGE_EXPORT bool matchesPath(const QString& path, const QString&
  * @param typedFragments the fragments which were typed
  * @return bool true if match, else false
  */
-KDEVPLATFORMLANGUAGE_EXPORT bool matchesAbbreviationMulti(const QString& word, const QStringList& typedFragments);
+KDEVPLATFORMLANGUAGE_EXPORT bool matchesAbbreviationMulti(QStringView word, const QStringList& typedFragments);
 
 /**
  * @brief Matches a path against a list of search fragments.
